#
# spec file for package python-audioread
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-audioread
Version:        2.1.8
Release:        bp155.2.13
Summary:        Wrapper for audio decoding via selectable backends
License:        MIT
Group:          Development/Languages/Python
Url:            https://github.com/sampsyo/audioread
Source0:        https://github.com/beetbox/audioread/archive/v%{version}.tar.gz
BuildRequires:  %{python_module base}
BuildRequires:  %{python_module pytest-runner}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  ffmpeg
BuildRequires:  python-rpm-macros
BuildArch:      noarch
Recommends:     ffmpeg
Recommends:     python-gobject
Recommends:     python-pymad
Recommends:     typelib(Gst) = 1.0

%python_subpackages

%description
Decode audio files using whichever backend is available. The library
currently supports:

- Gstreamer via PyGObject.
- MAD via the pymad bindings.
- FFmpeg or Libav via its command-line interface.
- The standard library wave, aifc, and sunau modules (for
  uncompressed audio formats).

%prep
%setup -q -n audioread-%{version}

%build
%python_build

%install
%python_install

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Wed Jul 31 2019 pgajdos@suse.com
- version update to 2.1.8
  * Fix an unhandled ``OSError`` when FFmpeg is not installed.
  * Properly close some filehandles in the FFmpeg backend (thanks to
    @RyanMarcus and @ssssam).
  * The maddec backend now always produces bytes objects, like the other
    backends (thanks to @ssssam).
  * Resolve an audio data memory leak in the GStreamer backend (thanks again to
    @ssssam).
  * You can now optionally specify which specific backends ``audio_open`` should
    try (thanks once again to @ssssam).
- deleted patches
  - 0001-maddec-Ensure-that-the-audio-blocks-are-of-type-bytes.patch (upstreamed)
- deleted sources
  - LICENSE (not needed)
* Mon Feb 25 2019 Antonio Larrosa <alarrosa@suse.com>
- Add 0001-maddec-Ensure-that-the-audio-blocks-are-of-type-bytes.patch
  to ensure audio blocks are always of type bytes (and not sometimes
  bytearray when using maddec).
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sat Nov  3 2018 Todd R <toddrme2178@gmail.com>
- Update to 2.1.6
  * Fix a "no such process" crash in the FFmpeg backend on Windows
    Subsystem for Linux (thanks to @llamasoft).
  * Avoid suppressing SIGINT in the GStreamer backend on older
    versions of PyGObject (thanks to @lazka).
- Recommend dependencies needed for full functionality.
- Include license file
* Thu Sep 28 2017 alarrosa@suse.com
- Update to 2.1.5
  * Properly clean up the file handle when a backend fails to decode a file.
  * Fix parsing of "N.M" channel counts in the FFmpeg backend.
  * Avoid a crash in the raw backend when a file uses an unsupported
    number of bits per sample (namely, 24-bit samples in Python < 3.4).
  * Add a __version__ value to the package.
* Sat Aug 12 2017 jengelh@inai.de
- Trim author list and redundant license info. Improve summary.
* Fri Apr 21 2017 alarrosa@suse.com
- Use singlespec macros
* Wed Jan 18 2017 alarrosa@suse.com
- Initial package release
  2.1.4
    Fix a bug in the FFmpeg backend where, after closing a file, the program's
    standard input stream would be "broken" and wouldn't receive any input.
  2.1.3
    Avoid some warnings in the GStreamer backend when using modern versions of
    GLib. We now require at least GLib 2.32.
  2.1.2
    Fix a file descriptor leak when opening and closing many files using
    GStreamer.
  2.1.1
    Just fix ReST formatting in the README.
  2.1.0
    The FFmpeg backend can now also use Libav's ``avconv`` command.
    Fix a warning by requiring GStreamer >= 1.0.
    Fix some Python 3 crashes with the new GStreamer backend (thanks to
    @xix-xeaon).
  2.0.0
    The GStreamer backend now uses GStreamer 1.x via the new
    gobject-introspection API (and is compatible with Python 3).
  1.2.2
    When running FFmpeg on Windows, disable its crash dialog. Thanks to
    jcsaaddupuy.
  1.2.1
    Fix an unhandled exception when opening non-raw audio files (thanks to
    aostanin).
    Fix Python 3 compatibility for the raw-file backend.
  1.2.0
    Add support for FFmpeg on Windows (thanks to Jean-Christophe Saad-Dupuy).
  1.1.0
    Add support for Sun/NeXT `Au files`_ via the standard-library ``sunau``
    module (thanks to Dan Ellis).
  1.0.3
    Use the rawread (standard-library) backend for .wav files.
  1.0.2
    Send SIGKILL, not SIGTERM, to ffmpeg processes to avoid occasional hangs.
  1.0.1
    When GStreamer fails to report a duration, raise an exception instead of
    silently setting the duration field to None.
